@@ -72,7 +72,7 @@ sub pre_git {
     details($repo);
 
     # print mirror status if at least one slave status file is present
-    print_status( $repo ) if $mode ne 'local' and glob("$rc{GL_REPO_BASE}/$repo.git/gl-slave-*.status");
+    print_status( $repo ) if not $rc{HUSH_MIRROR_STATUS} and $mode ne 'local' and glob("$rc{GL_REPO_BASE}/$repo.git/gl-slave-*.status");
 
     # we don't deal with any reads.  Note that for pre-git this check must
     # happen *after* getting details, to give mode() a chance to die on "known
@@ -244,8 +244,10 @@ sub push_to_slaves {
 
 sub print_status {
     my $repo = shift;
-    delete local $ENV{GL_USER};
+    my $u = $ENV{GL_USER};
+    delete $ENV{GL_USER};
     system("gitolite mirror status all $repo >&2");
+    $ENV{GL_USER} = $u;
 }
 
 1;
